gdg - generation data groups with python
========================================

Features
--------

- TODO

Quick start
-----------

Installation:

.. code-block:: console

    $ pip install gdg

Use:

.. code-block:: pycon

    >>> import gdg

    >>> g = gdg.Gdg()


Source Code
===========


Changelog
=========

Version 0.0.0
-------------

-  2021/02/02. Pre-Alpha
